@@ -43,7 +43,7 @@ typedef struct _EphyLocationEntryPrivate	EphyLocationEntryPrivate;
 
 struct _EphyLocationEntryClass
 {
-	GtkToolItemClass parent_class;
+	GtkEntryClass parent_class;
 
 	/* Signals */
 	void   (* user_changed)	(EphyLocationEntry *entry);
@@ -55,12 +55,16 @@ struct _EphyLocationEntryClass
 
 struct _EphyLocationEntry
 {
-	GtkToolItem parent_object;
+	GtkEntry parent_object;
 
 	/*< private >*/
 	EphyLocationEntryPrivate *priv;
 };
 
+#define STOCK_LOCK_INSECURE        "lock-insecure"
+#define STOCK_LOCK_SECURE          "lock-secure"
+#define STOCK_LOCK_BROKEN          "lock-broken"
+
 GType		ephy_location_entry_get_type		(void);
 
 GtkWidget      *ephy_location_entry_new			(void);
@@ -97,8 +101,6 @@ void		ephy_location_entry_undo_reset		(EphyLocationEntry *entry);
 
 void		ephy_location_entry_activate		(EphyLocationEntry *entry);
 
-GtkWidget      *ephy_location_entry_get_entry		(EphyLocationEntry *entry);
-
 void		ephy_location_entry_set_favicon		(EphyLocationEntry *entry,
 							 GdkPixbuf *pixbuf);
 
