@@ -38,7 +38,6 @@
 #include "ephy-settings.h"
 #include "ephy-shell.h"
 #include "ephy-state.h"
-#include "ephy-stock-icons.h"
 #include "ephy-topic-action.h"
 #include "ephy-window.h"
 #include "popup-commands.h"
@@ -157,18 +156,18 @@ static const GtkActionEntry ephy_bookmark_popup_entries [] = {
 	{ "PopupAction", NULL, "" },
 
 	/* File Menu*/
-	{ "NewTopic", GTK_STOCK_NEW, N_("_New Topic"), "<control>N",
+	{ "NewTopic", NULL, N_("_New Topic"), "<control>N",
 	  N_("Create a new topic"), 
 	  G_CALLBACK (cmd_add_topic) },
-	{ "OpenInWindow", GTK_STOCK_OPEN, N_("Open in New _Window"), "<control>O",
+	{ "OpenInWindow", NULL, N_("Open in New _Window"), "<control>O",
 	  N_("Open the selected bookmark in a new window"), 
 	  G_CALLBACK (cmd_open_bookmarks_in_browser) },
-	{ "OpenInTab", STOCK_NEW_TAB, N_("Open in New _Tab"), "<shift><control>O",
+	{ "OpenInTab", NULL, N_("Open in New _Tab"), "<shift><control>O",
 	  N_("Open the selected bookmark in a new tab"), 
 	  G_CALLBACK (cmd_open_bookmarks_in_tabs) },
 	{ "Rename", NULL, N_("_Rename…"), "F2",
 	  N_("Rename the selected bookmark or topic"), G_CALLBACK (cmd_rename) },
-	{ "Properties", GTK_STOCK_PROPERTIES, N_("_Properties"), "<alt>Return",
+	{ "Properties", NULL, N_("_Properties"), "<alt>Return",
 	  N_("View or modify the properties of the selected bookmark"), 
 	  G_CALLBACK (cmd_bookmark_properties) },
 	{ "Import", NULL, N_("_Import Bookmarks…"), NULL,
@@ -177,32 +176,32 @@ static const GtkActionEntry ephy_bookmark_popup_entries [] = {
 	{ "Export", NULL, N_("_Export Bookmarks…"), NULL,
 	  N_("Export bookmarks to a file"), 
 	  G_CALLBACK (cmd_bookmarks_export) },	  
-	{ "Close", GTK_STOCK_CLOSE, N_("_Close"), "<control>W",
+	{ "Close", NULL, N_("_Close"), "<control>W",
 	  N_("Close the bookmarks window"), 
 	  G_CALLBACK (cmd_close) },
 
 	/* Edit Menu */
-	{ "Cut", GTK_STOCK_CUT, N_("Cu_t"), "<control>X",
+	{ "Cut", NULL, N_("Cu_t"), "<control>X",
 	  N_("Cut the selection"), 
 	  G_CALLBACK (cmd_cut) },
-	{ "Copy", GTK_STOCK_COPY, N_("_Copy"), "<control>C",
+	{ "Copy", NULL, N_("_Copy"), "<control>C",
 	  N_("Copy the selection"), 
 	  G_CALLBACK (cmd_copy) },
-	{ "Paste", GTK_STOCK_PASTE, N_("_Paste"), "<control>V",
+	{ "Paste", NULL, N_("_Paste"), "<control>V",
 	  N_("Paste the clipboard"), 
 	  G_CALLBACK (cmd_paste) },
-	{ "Delete", GTK_STOCK_DELETE, N_("_Delete"), "<control>T",
+	{ "Delete", NULL, N_("_Delete"), "<control>T",
 	  N_("Delete the selected bookmark or topic"), 
 	  G_CALLBACK (cmd_delete) },
-	{ "SelectAll", GTK_STOCK_SELECT_ALL, N_("Select _All"), "<control>A",
+	{ "SelectAll", NULL, N_("Select _All"), "<control>A",
 	  N_("Select all bookmarks or text"), 
 	  G_CALLBACK (cmd_select_all) },
 	
 	/* Help Menu */	
-	{ "HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1",
+	{ "HelpContents", NULL, N_("_Contents"), "F1",
 	  N_("Display bookmarks help"), 
 	  G_CALLBACK (cmd_help_contents) },
-	{ "HelpAbout", GTK_STOCK_ABOUT, N_("_About"), NULL,
+	{ "HelpAbout", NULL, N_("_About"), NULL,
 	  N_("Display credits for the web browser creators"),
 	  G_CALLBACK (window_cmd_help_about) },
 };
@@ -1519,7 +1518,6 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 	ephy_gui_ensure_window_group (GTK_WINDOW (editor));
 
 	gtk_window_set_title (GTK_WINDOW (editor), _("Bookmarks"));
-	gtk_window_set_icon_name (GTK_WINDOW (editor), EPHY_STOCK_BOOKMARKS);
 
 	g_signal_connect (editor, "delete_event",
 			  G_CALLBACK (delete_event_cb), NULL);
