@@ -38,18 +38,11 @@
 #include <gtk/gtk.h>
 #include <webkit/webkit.h>
 
-#define HISTORY_ITEM_DATA_KEY "HistoryItem"
-
 #define EPHY_NAVIGATION_HISTORY_ACTION_GET_PRIVATE(object)		\
   (G_TYPE_INSTANCE_GET_PRIVATE ((object),				\
 				EPHY_TYPE_NAVIGATION_HISTORY_ACTION,	\
 				EphyNavigationHistoryActionPrivate))
 
-typedef enum {
-  WEBKIT_HISTORY_BACKWARD,
-  WEBKIT_HISTORY_FORWARD
-} WebKitHistoryType;
-
 struct _EphyNavigationHistoryActionPrivate {
   EphyNavigationHistoryDirection direction;
   EphyHistory *history;
@@ -63,7 +56,7 @@ enum {
 static void ephy_navigation_history_action_init       (EphyNavigationHistoryAction *action);
 static void ephy_navigation_history_action_class_init (EphyNavigationHistoryActionClass *klass);
 
-G_DEFINE_TYPE (EphyNavigationHistoryAction, ephy_navigation_history_action, EPHY_TYPE_NAVIGATION_ACTION)
+G_DEFINE_TYPE (EphyNavigationHistoryAction, ephy_navigation_history_action, EPHY_TYPE_LINK_ACTION)
 
 static void
 ephy_history_cleared_cb (EphyHistory *history,
@@ -81,14 +74,19 @@ action_activate (GtkAction *action)
   WebKitWebView *web_view;
 
   history_action = EPHY_NAVIGATION_HISTORY_ACTION (action);
-  window = _ephy_navigation_action_get_window (EPHY_NAVIGATION_ACTION (action));
+  window = ephy_window_action_get_window (EPHY_WINDOW_ACTION (action));
   embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
   g_return_if_fail (embed != NULL);
 
   web_view = EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed);
 
+  /* We use ephy_link_action_get_button on top of
+   * ephy_gui_is_middle_click because of the hacks we have to do to
+   * fake middle clicks on tool buttons. Read the documentation of
+   * ephy_link_action_get_button for more details. */
   if (history_action->priv->direction == EPHY_NAVIGATION_HISTORY_DIRECTION_BACK) {
-    if (ephy_gui_is_middle_click ()) {
+    if (ephy_gui_is_middle_click () ||
+        ephy_link_action_get_button (EPHY_LINK_ACTION (history_action)) == 2) {
       embed = ephy_shell_new_tab (ephy_shell_get_default (),
                                   EPHY_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (embed))),
                                   embed,
@@ -97,8 +95,10 @@ action_activate (GtkAction *action)
       web_view = EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed);
     }
     webkit_web_view_go_back (web_view);
+    gtk_widget_grab_focus (GTK_WIDGET (embed));
   } else if (history_action->priv->direction == EPHY_NAVIGATION_HISTORY_DIRECTION_FORWARD) {
-    if (ephy_gui_is_middle_click ()) {
+    if (ephy_gui_is_middle_click () ||
+        ephy_link_action_get_button (EPHY_LINK_ACTION (history_action)) == 2) {
       const char *forward_uri;
       WebKitWebHistoryItem *forward_item;
       WebKitWebBackForwardList *history;
@@ -120,6 +120,7 @@ action_activate (GtkAction *action)
       webkit_web_view_load_uri (web_view, forward_uri);
     } else {
       webkit_web_view_go_forward (web_view);
+      gtk_widget_grab_focus (GTK_WIDGET (embed));
     }
   }
 }
